using System;
using System.IO;

namespace Siberix.Examples
{
	class Example
	{
		static void Main(string[] args)
		{
			// Report
			Siberix.Report.Report report = new Siberix.Report.Report();

			// Callback
			report.Callback = new Callback();

			// Load
			report.Load("../../Catalog.xml");

			// Publish
			report.Publish("Catalog.pdf", Siberix.Report.FileFormat.PDF);
			report.Publish("Catalog.xps", Siberix.Report.FileFormat.XPS);

			// View
			System.Diagnostics.Process process = new System.Diagnostics.Process();
			System.Diagnostics.ProcessStartInfo info = new System.Diagnostics.ProcessStartInfo("Catalog.pdf");
			process.StartInfo = info;
			process.Start();
		}

		public class Callback : Siberix.Report.ICallback
		{
			public void OnInjector(string id, Report.IElement element)
			{
				if (element.Type != Report.ElementType.Group)
					return;

				Siberix.Report.IGroup group = (Siberix.Report.IGroup)element;

				if (id.Equals("TOC"))
				{
					// Styles
					Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(8), Siberix.Graphics.Brushes.White);

					System.Xml.XmlDocument xmlDoc = new System.Xml.XmlDocument();

					xmlDoc.Load("../../Images/Description.xml");

					Siberix.Report.Grid.IGrid grid = group.AddGrid();
					grid.Spacings.Left = 5;

					Siberix.Report.Grid.IColumn column = grid.AddColumn();
					column.Width = new Siberix.Report.RelativeWidth(90);

					column = grid.AddColumn();
					column.Width = new Siberix.Report.RelativeWidth(10);

					foreach (System.Xml.XmlNode category in xmlDoc.ChildNodes[1])
					{
						System.Xml.XmlNode xmlNode = category.Attributes.GetNamedItem("Name");

						Siberix.Report.Grid.IRow row = grid.AddRow();
						row.Spacings.Top = 5;

						Siberix.Report.Grid.ICell cell = row.AddCell();

						Siberix.Report.Text.IText text = cell.AddText();
						text.Style = style1;
						text.Width = new Siberix.Report.RelativeWidth(100);
						text.AddContent(xmlNode.Value, new Siberix.Report.Text.Hyperlink(xmlNode.Value));
						text.Leader = new Siberix.Report.Text.Leader(".");

						cell = row.AddCell();

						Siberix.Report.IPageReference pr = cell.AddPageReference(xmlNode.Value);
						pr.Style = style1;
						pr.Alignment = Siberix.Report.NumberAlignment.Left;
					}
				}

				if (id.Equals("Items"))
				{
					// Styles
					Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(14), new Siberix.Graphics.SolidColorBrush(new Siberix.Graphics.Color(46, 0, 69)));
					Siberix.Report.Text.Style style2 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(12), new Siberix.Graphics.SolidColorBrush(new Siberix.Graphics.Color(46, 0, 69)));
					Siberix.Report.Text.Style style3 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.ArialBold(8), Siberix.Graphics.Brushes.Black);
					Siberix.Report.Text.Style style4 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(8), Siberix.Graphics.Brushes.Black);

					System.Xml.XmlDocument xmlDoc = new System.Xml.XmlDocument();

					xmlDoc.Load("../../Images/Description.xml");

					foreach (System.Xml.XmlNode category in xmlDoc.ChildNodes[1])
					{
						System.Xml.XmlNode xmlNode = category.Attributes.GetNamedItem("Name");

						Siberix.Report.Text.IText text = group.AddText();
						text.Style = style1;
						text.Id = xmlNode.Value;
						text.Spacings.Vertical = 10;
						text.AddContent(xmlNode.Value);

						bool first = true;

						foreach (System.Xml.XmlNode ring in category.ChildNodes)
						{
							if (first)
							{
								first = false;
								text.KeepWithNext = true;
							}

							Siberix.Report.Grid.IGrid grid = group.AddGrid();
							grid.Spacings.Top = 5;
							grid.Spacings.Bottom = 5;
							grid.KeepSolid = true;

							Siberix.Report.Grid.IColumn column = grid.AddColumn();
							column.Width = new Siberix.Report.RelativeWidth(30);

							column = grid.AddColumn();
							column.Width = new Siberix.Report.RelativeWidth(30);

							column = grid.AddColumn();
							column.Width = new Siberix.Report.RelativeWidth(40);

							Siberix.Report.Grid.IRow row = grid.AddRow();

							xmlNode = ring.Attributes.GetNamedItem("Image");

							Siberix.Report.Grid.ICell cell = row.AddCell();
							cell.RowSpan = 7;
							cell.Alignment.Horizontal = Siberix.Report.HorizontalAlignment.Center;
							cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle;
							cell.Borders = new Siberix.Report.Borders(new Siberix.Graphics.Pen(new Siberix.Graphics.Color(46, 0, 69), 1, Siberix.Graphics.DashStyle.Dot), 5);
							cell.Paddings.All = 5;

							Siberix.Report.IImage img = cell.AddImage(new Siberix.Graphics.Image(xmlNode.Value));

							xmlNode = ring.Attributes.GetNamedItem("Name");

							cell = row.AddCell();
							cell.Paddings.All = 5;
							cell.ColSpan = 2;

							text = cell.AddText();
							text.Style = style2;
							text.Spacings.Left = 20;
							text.AddContent(xmlNode.Value);

							row = grid.AddRow();

							xmlNode = ring.Attributes.GetNamedItem("MetalType");

							cell = row.AddCell();
							cell.Paddings.All = 2;

							text = cell.AddText();
							text.Style = style3;
							text.Width = new Siberix.Report.RelativeWidth(100);
							text.Alignment = Siberix.Report.TextAlignment.Right;
							text.AddContent("Metal Type :");

							cell = row.AddCell();
							cell.Paddings.All = 2;

							text = cell.AddText();
							text.Style = style4;
							text.AddContent(xmlNode.Value);

							row = grid.AddRow();

							xmlNode = ring.Attributes.GetNamedItem("BandWidth");

							cell = row.AddCell();
							cell.Paddings.All = 2;

							text = cell.AddText();
							text.Style = style3;
							text.Width = new Siberix.Report.RelativeWidth(100);
							text.Alignment = Siberix.Report.TextAlignment.Right;
							text.AddContent("Band Width :");

							cell = row.AddCell();
							cell.Paddings.All = 2;

							text = cell.AddText();
							text.Style = style4;
							text.AddContent(xmlNode.Value);

							row = grid.AddRow();

							xmlNode = ring.Attributes.GetNamedItem("BandStyle");

							cell = row.AddCell();
							cell.Paddings.All = 2;

							text = cell.AddText();
							text.Style = style3;
							text.Width = new Siberix.Report.RelativeWidth(100);
							text.Alignment = Siberix.Report.TextAlignment.Right;
							text.AddContent("Band Style :");

							cell = row.AddCell();
							cell.Paddings.All = 2;

							text = cell.AddText();
							text.Style = style4;
							text.AddContent(xmlNode.Value);

							row = grid.AddRow();

							xmlNode = ring.Attributes.GetNamedItem("MainStone");

							cell = row.AddCell();
							cell.Paddings.All = 2;

							text = cell.AddText();
							text.Style = style3;
							text.Width = new Siberix.Report.RelativeWidth(100);
							text.Alignment = Siberix.Report.TextAlignment.Right;
							text.AddContent("Main Stone :");

							cell = row.AddCell();
							cell.Paddings.All = 2;

							text = cell.AddText();
							text.Style = style4;
							text.AddContent(xmlNode.Value);

							row = grid.AddRow();

							xmlNode = ring.Attributes.GetNamedItem("MainStoneSetting");

							cell = row.AddCell();
							cell.Paddings.All = 2;

							text = cell.AddText();
							text.Style = style3;
							text.Width = new Siberix.Report.RelativeWidth(100);
							text.Alignment = Siberix.Report.TextAlignment.Right;
							text.AddContent("Main Stone Setting :");

							cell = row.AddCell();
							cell.Paddings.All = 2;

							text = cell.AddText();
							text.Style = style4;
							text.AddContent(xmlNode.Value);

							row = grid.AddRow();

							xmlNode = ring.Attributes.GetNamedItem("ItemWeight");

							cell = row.AddCell();
							cell.Paddings.All = 2;

							text = cell.AddText();
							text.Style = style3;
							text.Width = new Siberix.Report.RelativeWidth(100);
							text.Alignment = Siberix.Report.TextAlignment.Right;
							text.AddContent("Item Weight :");

							cell = row.AddCell();
							cell.Paddings.All = 2;

							text = cell.AddText();
							text.Style = style4;
							text.AddContent(xmlNode.Value);
						}
					}
				}
			}

			public void OnInjector(string id, Report.Text.IText text, Report.Text.Style style, Report.Text.Hyperlink hyperlink)
			{

			}

			public string OnMergeCode(string name)
			{
				return "";
			}

			public Siberix.Report.IDrawing OnDrawing(string name)
			{
				return null;
			}

			public string ResolvePath(string path)
			{
				return path;
			}

			public Siberix.Report.Text.Style GetStyle(string name)
			{
				return null;
			}

			public Stream LoadFont(string path)
			{
				return null;
			}

			public Stream LoadImage(string path)
			{
				return null;
			}

			public Stream LoadMetafile(string path)
			{
				return null;
			}

			public void OnLoadStart(Report.IElement element)
			{

			}

			public void OnLoadEnd(Report.IElement element)
			{

			}
		}
	}
}