using System;
using System.IO;

namespace Siberix.Examples
{
	class Example
	{
		static void Main(string[] args)
		{
			// Report
			Siberix.Report.Report report = new Siberix.Report.Report();

			// Info
			report.Info.Title = "Example";
			report.Info.Author = "Siberix Technologies, Canada";
			report.Info.Creator = "Siberix Report Writer";
			report.Info.Copyright = "2003-2012 Siberix Technologies, Canada";

			// Section
			Siberix.Report.Section.ISection section = report.AddSection();
			section.Size = Siberix.Report.PageSize.Letter;
			section.Spacings.All = 25;

			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(12), Siberix.Graphics.Brushes.Black);

			System.Random rnd = new Random();

			int i = 0;

			while (i < 25)
			{
				// Grid
				Siberix.Report.Grid.IGrid grid = section.AddGrid();
				grid.Width = new Siberix.Report.DirectWidth(550); // The width has to be set to some fixed value.
				grid.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);

				Siberix.Report.Grid.IColumn column = grid.AddColumn();
				column.Width = new Siberix.Report.RelativeWidth(80);

				column = grid.AddColumn();
				column.Width = new Siberix.Report.RelativeWidth(20);

				while (true)
				{
					i++;

					if (i > 25)
						break;

					Siberix.Report.Grid.IRow row = grid.AddRow();

					Siberix.Report.Grid.ICell cell = row.AddCell();
					cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
					cell.Paddings.All = 5;

					Siberix.Report.Text.IText text = cell.AddText();
					text.Width = new Siberix.Report.RelativeWidth(100);
					text.Style = style1;
					text.AddContent("Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

					// Random spacings
					int k = rnd.Next(5);

					while (k > 0)
					{
						text.AddContent("\n");
						
						k--;
					}

					cell = row.AddCell();
					cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
					cell.Paddings.All = 5;

					text = cell.AddText();
					text.Width = new Siberix.Report.RelativeWidth(100);
					text.Style = style1;
					text.AddContent(i.ToString());

					Siberix.Graphics.Size sz = grid.Measure();

					if (sz.Height > 740)
					{
						grid.Remove(row);

						i--;

						section.AddPageBreak();

						break;
					}
				}
			}

			// Publish
			report.Publish("Document.pdf", Siberix.Report.FileFormat.PDF);
			report.Publish("Document.xps", Siberix.Report.FileFormat.XPS);

			// Save
			report.Save("Report.xml");

			// View
			System.Diagnostics.Process process = new System.Diagnostics.Process();
			System.Diagnostics.ProcessStartInfo info = new System.Diagnostics.ProcessStartInfo("Document.pdf");
			process.StartInfo = info;
			process.Start();
		}
	}
}