Module Example

    Sub Main()

        ' Report
        Dim report As Siberix.Report.Report = New Siberix.Report.Report()

        ' Info
        report.Info.Title = "Example"
        report.Info.Author = "Siberix Technologies, Canada"
        report.Info.Creator = "Siberix Report Writer"
        report.Info.Copyright = "2003-2012 Siberix Technologies, Canada"

        ' Section
        Dim section As Siberix.Report.Section.ISection = report.AddSection()
        section.Size = Siberix.Report.PageSize.Letter
        section.Spacings.All = 35

        ' Styles
        Dim style1 As Siberix.Report.Text.Style = New Siberix.Report.Text.Style(New Siberix.Graphics.Fonts.Arial(12), Siberix.Graphics.Brushes.Black)
        Dim style2 As Siberix.Report.Text.Style = New Siberix.Report.Text.Style(New Siberix.Graphics.Fonts.TimesNewRomanBold(450), New Siberix.Graphics.LinearGradientBrush(Siberix.Graphics.Colors.Yellow, Siberix.Graphics.Colors.Red, 15.0F))

        ' Page Numbering
        Dim footer As Siberix.Report.Section.IFooter = section.AddFooter()
        footer.Height = New Siberix.Report.DirectHeight(30)

        Dim pn As Siberix.Report.IPageNumber = footer.AddPageNumber(600, 5)
        pn.Style = style1
        pn.Format = Siberix.Report.NumberFormat.Decimal
        pn.Template = "Page {0} of {1}"
        pn.Alignment = Siberix.Report.NumberAlignment.Right

        For i As Integer = 1 To 3

            Dim text As Siberix.Report.Text.IText = section.AddText()
            text.Style = style2
            text.Spacings.Left = 150
            text.Spacings.Top = 100
            text.AddContent(i.ToString())

            If i < 3 Then
                section.AddPageBreak()
            End If

        Next

        ' Generate
        Dim pages As Siberix.Report.IPageCollection = report.Generate()

        Dim scale As Single = 0.25 ' 25%

        Dim pageNumber As Integer = 1

        For Each page As Siberix.Report.IPage In pages

            SavePNG(page, scale, pageNumber)
            SaveEMF(page, scale, pageNumber)

            pageNumber += 1

        Next

        ' Publish
        report.Publish("Document.pdf", Siberix.Report.FileFormat.PDF)
        report.Publish("Document.xps", Siberix.Report.FileFormat.XPS)

        ' Save
        report.Save("Report.xml")

        ' View
        Dim process As System.Diagnostics.Process = New System.Diagnostics.Process()
        Dim info As System.Diagnostics.ProcessStartInfo = New System.Diagnostics.ProcessStartInfo("Document.pdf")
        process.StartInfo = info
        process.Start()

    End Sub

    Sub SavePNG(ByVal page As Siberix.Report.IPage, ByVal scale As Single, ByVal pageNumber As Integer)

        Dim width As Integer = Siberix.Report.Utils.PointsToPixels(page.Width * scale)
        Dim height As Integer = Siberix.Report.Utils.PointsToPixels(page.Height * scale)

        Dim bmp As System.Drawing.Bitmap = New System.Drawing.Bitmap(width, height, System.Drawing.Imaging.PixelFormat.Format24bppRgb)

        Dim g As System.Drawing.Graphics = System.Drawing.Graphics.FromImage(bmp)

        Dim graphics As Siberix.Wrappers.GDIPlus.Graphics = New Siberix.Wrappers.GDIPlus.Graphics(g)

        graphics.Scale(scale, scale)

        page.Draw(graphics)

        graphics.Flush()

        Dim fileName As String = "image" + pageNumber.ToString() + ".png"

        bmp.Save(fileName, System.Drawing.Imaging.ImageFormat.Png)

        g.Dispose()

        bmp.Dispose()

    End Sub

    Sub SaveEMF(ByVal page As Siberix.Report.IPage, ByVal scale As Single, ByVal pageNumber As Integer)

        Dim width As Integer = Siberix.Report.Utils.PointsToPixels(page.Width * scale)
        Dim height As Integer = Siberix.Report.Utils.PointsToPixels(page.Height * scale)

        Dim ms As System.IO.MemoryStream = New System.IO.MemoryStream()

        Dim bmp As System.Drawing.Bitmap = New System.Drawing.Bitmap(1, 1, System.Drawing.Imaging.PixelFormat.Format24bppRgb)

        Dim g As System.Drawing.Graphics = System.Drawing.Graphics.FromImage(bmp)

        Dim hdc As System.IntPtr = g.GetHdc()

        Dim metafile As System.Drawing.Imaging.Metafile = New System.Drawing.Imaging.Metafile(ms, hdc, New System.Drawing.Rectangle(0, 0, width, height), System.Drawing.Imaging.MetafileFrameUnit.Pixel, System.Drawing.Imaging.EmfType.EmfPlusDual)

        g.ReleaseHdc(hdc)
        g.Dispose()

        bmp.Dispose()

        Dim gm As System.Drawing.Graphics = System.Drawing.Graphics.FromImage(metafile)

        Dim graphics As Siberix.Wrappers.GDIPlus.Graphics = New Siberix.Wrappers.GDIPlus.Graphics(gm)

        graphics.Scale(scale, scale)

        page.Draw(graphics)

        graphics.Flush()

        gm.Dispose()

        metafile.Dispose()

        Dim fileName As String = "image" + pageNumber.ToString() + ".emf"

        Dim fs As System.IO.FileStream = New System.IO.FileStream(fileName, System.IO.FileMode.Create, System.IO.FileAccess.Write)

        fs.Write(ms.ToArray(), 0, ms.Length)

        fs.Close()

    End Sub

End Module
